import csv
from django.http import HttpResponse

from core.models import Student, SubmissionType, Submission
from core.custom_annotations import group_required


@group_required('Reviewers')
def export_csv(request):
    # Create the HttpResponse object with the appropriate CSV header.
    response = HttpResponse(content_type='text/csv')
    response['Content-Disposition'] = 'attachment; filename="grady_results.csv"'

    writer = csv.writer(response)
    writer.writerow(['Matrikel', 'Username',  'Name', 'Sum'] +
                    [s.name for s in SubmissionType.objects.all().order_by('name')])

    for student in Student.objects.all():
        submissions = Submission.objects.filter(student=student)
        score_list  = [s.feedback.score if hasattr(s, 'feedback') else 0 for s in submissions.order_by('type__name')]
        if not score_list:
            score_list = [0] * SubmissionType.objects.count()
        writer.writerow([
            student.matrikel_no,
            student.user.username,
            student.name,
            sum(score_list),
            *score_list
        ])

    return response
