from django.utils.decorators import method_decorator
from django.views.generic import DetailView
from django.shortcuts import render
from django.urls import reverse
from django.http import HttpResponseRedirect

from core.custom_annotations import group_required, in_groups
from core.models import Submission, Feedback


class SubmissionView(DetailView):

    template_name = 'core/submission_view.html'
    model = Submission

    @method_decorator(group_required('Reviewers', 'Students'))
    def dispatch(self, *args, **kwargs):
        return super(SubmissionView, self).dispatch(*args, **kwargs)

    def get_object(self):
        obj = Submission.objects.get(slug=self.kwargs['slug'])
        if in_groups(self.request.user, ('Students', )) and hasattr(obj, 'feedback') and obj.feedback.status == Feedback.ACCEPTED:
            obj.seen = True
            obj.save()
        return obj

    def get_context_data(self, **kwargs):
        context = super(SubmissionView, self).get_context_data(**kwargs)
        context['is_reviewer'] = in_groups(self.request.user, ('Reviewers', ))
        return context

@group_required('Reviewers')
def create_feedback_for_submission(request, slug):

    submission = Submission.objects.get(slug=slug)

    submission.feedback = Feedback()
    submission.feedback.of_reviewer   = request.user
    submission.feedback.of_tutor      = request.user
    submission.feedback.of_submission = submission

    submission.feedback.save()
    submission.save()

    return HttpResponseRedirect(reverse('FeedbackEdit', args=(submission.feedback.slug,)))

@group_required('Reviewers')
def get_submission_list(request):
    context = {
        'submission_list': Submission.objects.all(),
    }
    return render(request, 'core/student_submission_list.html', context)

